==> breeze_website_builder_6.1.20.tar.gz: manage/backup_restore.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 2/11/2016	ELL
//
	
	include ("check_session.php");
	
	$password = $_REQUEST['password'];
	
?>
<!DOCTYPE html>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Breeze Website Builder</title>

<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
<link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">

<style type="text/css">
#help_button	{
	position:relative;
	display:block;
	top:-15px;
	left:215px;
	height:31px;
	width:31px;
	z-index:100;
}
#backup_btn	{	width:80px;	}
#restore_btn	{	width:80px;	}
#backup_restore_login_btn	{
	width:100px;
	position:inherit;
}
#select_backup_to_upload_btn	{	width:440px;	}
</style>

<script src="js/hash.js"> </script>
<script src="js/mouse_position.js"></script>
<script src="js/popup_msg.js"></script>
<script src="js/jquery.min.js"></script>
<script src="js/backup_restore.js"></script>

<script>
<?php
	echo "	var theme = \"" . $theme . "\";\n\n";
	echo "	var pss = \"" . $password . "\";\n\n";
	echo "	var BACKUP_RESTORE_SELECT_BACKUP = \"" . BACKUP_RESTORE_SELECT_BACKUP . "\";\n";
	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
	echo "	var BACKUP_RESTORE_DELETE_BACKUP = \"" . BACKUP_RESTORE_DELETE_BACKUP . "\";\n";
	echo "	var BACKUP_RESTORE_RESTORE_CONFIRM_1_MSG = \"" . BACKUP_RESTORE_RESTORE_CONFIRM_1_MSG . "\";\n";
	echo "	var BACKUP_RESTORE_RESTORE_CONFIRM_2_MSG = \"" . BACKUP_RESTORE_RESTORE_CONFIRM_2_MSG . "\";\n";
	echo "	var BACKUP_RESTORE_DELETE_BACKUP_CONFIRM_MSG = \"" . BACKUP_RESTORE_DELETE_BACKUP_CONFIRM_MSG . "\";\n";
	echo "	var BACKUP_RESTORE_DELETE_BACKUP_SUCCESS_MSG = \"" . BACKUP_RESTORE_DELETE_BACKUP_SUCCESS_MSG . "\";\n";
	echo "	var BACKUP_RESTORE_DELETE_BACKUP_ERROR_ERR = \"" . BACKUP_RESTORE_DELETE_BACKUP_ERROR_ERR . "\";\n";
?>
</script>

</head>

<body <?php if (!$password) { ?>onLoad="document.getElementById('password_input').focus();"<?php } ?>>
<?php
	if (!$password)
	{
?>
        <form action="backup_restore.php" method="post" enctype="multipart/form-data" name="formLogin" id="formLogin">
        <p class="title" align="center"><?php echo INSTALL_PLUGIN_PLEASE_ENTER_PASSWORD_FOR_ADMIN; ?>:</p>
        <p align="center"><input name="password_input" id="password_input" type="password" onKeyDown="checkForEnter(event);" /></p>
        <input type="hidden" name="password" id="password" />
        <p align="center">
        <table align="center" border="0"><tr><td>
        <div class='button_console' id="backup_restore_login_btn" onClick="SubmitLogin();"><span class='button_console_text'><?php echo LOGIN_LOGIN_BTN; ?></span></div>
        </td></tr></table>
        </p>
        </form>
<?php
	}
	else
	{
		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "users WHERE `UserID` = 'admin'";
		$result = $bwb_dbh->query($query);
		$row = $result->fetch(PDO::FETCH_ASSOC);
		
		/////////////////////////////////////////////
		//Decrypt password for comparison:
		$enc_text = stripslashes($row["password"]);
		$key = stripslashes($row["UserID"]);
		
		//Convert key to codes and pad as necessary.
		for( $i = 0; $i < (strlen($enc_text))/2; $i++)
		{
			if ($i < strlen($key))
			{
				$c = $key{$i};
				$k[$i] = ord($c);
			}
			else
				$k[$i] = 65 + $i;
		}
		
		//Convert encrypted string to array of HEX uni-character codes.
		$j = 0;
		$q = 0;
		for( $i = 0; $i < strlen($enc_text); $i++)
		{
			if ($j == 0) {
				$c = $enc_text{$i};
				$j++;
			}
			else {
				$c = $c.$enc_text{$i};
				$e[$q] = hexdec($c);
				$q++;
				$j = 0;
			}
			
		}
		
		//Decrypt encrypted string with key to get original data.
		$decrypt_text = "";
		for( $i = 0; $i < (strlen($enc_text))/2; $i++)
		{
			$a[$i] = $e[$i] ^ $k[$i];
			$decrypt_text = $decrypt_text. chr($a[$i]);
		}
		////////////////////////////////////////////////////
		
		$decrypt_text = str_replace(BWB_SALT, '', $decrypt_text);
		$password_lookup = hash('sha256', $decrypt_text);
		if ($password_lookup == $password)
		{
?>

<table width="80%" align="center" border="0"><tr><td>
<div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo BACKUP_RESTORE_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
</td></tr></table>

<center>
<div class='button_console' id="backup_btn" onClick="window.location='backup_site.php?password=<?php echo $password; ?>';"><span class='button_console_text'><?php echo BACKUP_WORD; ?></span></div>
<hr style="width:80%;" />

<div id="backups_div">&nbsp;</div>

<h2 id="or">- <?php echo OR_CAP_WORD; ?> -</h2>
</center>

<form name="frmUploadPlugin" id="frmUploadBackup" action="restore_site.php" method="post" enctype="multipart/form-data">
<table width="80%" align="center">
	<tr><td align="center"><div class="button_heading_sub_level_1" id="select_backup_to_upload_btn"><div class="button_heading_text_sub_level_1"><?php echo BACKUP_RESTORE_SELECT_BACKUP_TO_UPLOAD; ?></div></div></td></tr>
	<tr><td align="center"><input name="backup_file" id="backup_file" type="file" /></td></tr>
    <tr><td align="center">
    <div class='button_console' id="restore_btn" onClick="document.getElementById('uploading_gif').style.display = 'inline'; document.getElementById('frmUploadBackup').submit();"><span class='button_console_text'><?php echo RESTORE_WORD; ?></span></div>
    </td></tr>
    <tr><td align="center"><img src="theme/<?php echo $theme; ?>/images/uploading.gif" alt="<?php echo BACKUP_RESTORE_UPLOADING_BACKUP_PLEASE_WAIT_MSG; ?>" id="uploading_gif" style="display:none; margin-top:50px;" /></td></tr>
</table>
<input type="hidden" name="password" value="<?php echo $password; ?>" />
</form>

<?php
		}
		else
			echo LOGIN_PASSWORD_NOT_CONFIRMED_1_MSG . " " . CLICK_WORD . " <a href='backup_restore.php'> " . HERE_WORD . " </a> " . LOGIN_PASSWORD_NOT_CONFIRMED_2_MSG;
	}
?>

<?php include("lib/popup_msg.html"); ?>

<script>
	HidePopupMsg();
<?php	if ($password)	{	?>
	GetBackups();
<?php }	?>
</script>

</body>
</html>

==> breeze_website_builder_6.5.02.tar.gz: manage/backup_restore.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 2/11/2016	ELL
// Revised: 7/27/2016	ELL
// Added switch to empty all image and media folders.
//
	
	include ("check_session.php");
	
	if ($access_level != "admin")
		exit;
	
	$password = $_REQUEST['password'];
	
?>
<!DOCTYPE html>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Breeze Website Builder</title>

<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
<link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">

<style type="text/css">
#help_button	{
	position:relative;
	display:block;
	top:-15px;
	left:215px;
	height:31px;
	width:31px;
	z-index:100;
}
#backup_btn	{	width:80px;	}
#restore_btn	{	width:80px;	}
#backup_restore_login_btn	{
	width:100px;
	position:inherit;
}
#select_backup_to_upload_btn	{	width:500px;	}
</style>

<script src="js/hash.js"> </script>
<script src="js/mouse_position.js"></script>
<script src="js/popup_msg.js"></script>
<script src="js/jquery.min.js"></script>
<script src="js/backup_restore.js"></script>

<script>
<?php
	echo "	var theme = \"" . $theme . "\";\n\n";
	echo "	var pss = \"" . $password . "\";\n\n";
	echo "	var BACKUP_RESTORE_SELECT_BACKUP = \"" . BACKUP_RESTORE_SELECT_BACKUP . "\";\n";
	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
	echo "	var BACKUP_RESTORE_DELETE_BACKUP = \"" . BACKUP_RESTORE_DELETE_BACKUP . "\";\n";
	echo "	var BACKUP_RESTORE_RESTORE_CONFIRM_1_MSG = \"" . BACKUP_RESTORE_RESTORE_CONFIRM_1_MSG . "\";\n";
	echo "	var BACKUP_RESTORE_RESTORE_CONFIRM_2_MSG = \"" . BACKUP_RESTORE_RESTORE_CONFIRM_2_MSG . "\";\n";
	echo "	var BACKUP_RESTORE_DELETE_BACKUP_CONFIRM_MSG = \"" . BACKUP_RESTORE_DELETE_BACKUP_CONFIRM_MSG . "\";\n";
	echo "	var BACKUP_RESTORE_DELETE_BACKUP_SUCCESS_MSG = \"" . BACKUP_RESTORE_DELETE_BACKUP_SUCCESS_MSG . "\";\n";
	echo "	var BACKUP_RESTORE_DELETE_BACKUP_ERROR_ERR = \"" . BACKUP_RESTORE_DELETE_BACKUP_ERROR_ERR . "\";\n";
?>
</script>

</head>

<body <?php if (!$password) { ?>onLoad="document.getElementById('password_input').focus();"<?php } ?>>
<?php
	if (!$password)
	{
?>
        <form action="backup_restore.php" method="post" enctype="multipart/form-data" name="formLogin" id="formLogin">
        <p class="title" align="center"><?php echo INSTALL_PLUGIN_PLEASE_ENTER_PASSWORD_FOR_ADMIN; ?>:</p>
        <p align="center"><input name="password_input" id="password_input" type="password" onKeyDown="checkForEnter(event);" /></p>
        <input type="hidden" name="password" id="password" />
        <p align="center">
        <table align="center" border="0"><tr><td>
        <div class='button_console' id="backup_restore_login_btn" onClick="SubmitLogin();"><span class='button_console_text'><?php echo LOGIN_LOGIN_BTN; ?></span></div>
        </td></tr></table>
        </p>
        </form>
<?php
	}
	else
	{
		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "users WHERE `UserID` = '" . $userid . "'";
		$result = $bwb_dbh->query($query);
		$row = $result->fetch(PDO::FETCH_ASSOC);
		
		/////////////////////////////////////////////
		//Decrypt password for comparison:
		$enc_text = stripslashes($row["password"]);
		$key = stripslashes($row["UserID"]);
		
		//Convert key to codes and pad as necessary.
		for( $i = 0; $i < (strlen($enc_text))/2; $i++)
		{
			if ($i < strlen($key))
			{
				$c = $key{$i};
				$k[$i] = ord($c);
			}
			else
				$k[$i] = 65 + $i;
		}
		
		//Convert encrypted string to array of HEX uni-character codes.
		$j = 0;
		$q = 0;
		for( $i = 0; $i < strlen($enc_text); $i++)
		{
			if ($j == 0) {
				$c = $enc_text{$i};
				$j++;
			}
			else {
				$c = $c.$enc_text{$i};
				$e[$q] = hexdec($c);
				$q++;
				$j = 0;
			}
			
		}
		
		//Decrypt encrypted string with key to get original data.
		$decrypt_text = "";
		for( $i = 0; $i < (strlen($enc_text))/2; $i++)
		{
			$a[$i] = $e[$i] ^ $k[$i];
			$decrypt_text = $decrypt_text. chr($a[$i]);
		}
		////////////////////////////////////////////////////
		
		$decrypt_text = str_replace(BWB_SALT, '', $decrypt_text);
		$password_lookup = hash('sha256', $decrypt_text);
		if ($password_lookup == $password)
		{
?>

<table width="80%" align="center" border="0"><tr><td>
<div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo BACKUP_RESTORE_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
</td></tr></table>

<center>
<div class='button_console' id="backup_btn" onClick="window.location='backup_site.php?password=<?php echo $password; ?>';"><span class='button_console_text'><?php echo BACKUP_WORD; ?></span></div>
<hr style="width:80%;" />

<div id="backups_div">&nbsp;</div>

<h2 id="or">- <?php echo OR_CAP_WORD; ?> -</h2>
</center>

<form name="frmUploadPlugin" id="frmUploadBackup" action="restore_site.php" method="post" enctype="multipart/form-data">
<table width="80%" align="center">
	<tr><td align="center"><div class="button_heading_sub_level_1" id="select_backup_to_upload_btn"><div class="button_heading_text_sub_level_1"><?php echo BACKUP_RESTORE_SELECT_BACKUP_TO_UPLOAD; ?></div></div></td></tr>
	<tr><td align="center"><input name="backup_file" id="backup_file" type="file" /></td></tr>
    <tr><td align="center">
    <div class='button_console' id="restore_btn" onClick="document.getElementById('uploading_gif').style.display = 'inline'; document.getElementById('frmUploadBackup').submit();"><span class='button_console_text'><?php echo RESTORE_WORD; ?></span></div>
    </td></tr>
    <tr><td align="right"><div style="position:relative; top:-50px"><input type="checkbox" name="retain_media_cb" id="retain_media_cb" onChange="SetRetainMedia(this.checked);" /> <?php echo BACKUP_RESTORE_RETAIN_MEDIA; ?></div></td></tr>
    <tr><td align="center"><img src="theme/<?php echo $theme; ?>/images/uploading.gif" alt="<?php echo BACKUP_RESTORE_UPLOADING_BACKUP_PLEASE_WAIT_MSG; ?>" id="uploading_gif" style="display:none; margin-top:50px;" /></td></tr>
    <tr><td align="right">
    <div class="small_message" style="width:200px; text-align:justify"><?php echo BACKUP_RESTORE_UPLOAD_LARGE_BKUPS_MSG; ?></div>
    </td></tr>
</table>
<input type="hidden" name="password" value="<?php echo $password; ?>" />
<input type="hidden" name="retain_media" id="retain_media" value="0" />
</form>

<?php
		}
		else
			echo LOGIN_PASSWORD_NOT_CONFIRMED_1_MSG . " " . CLICK_WORD . " <a href='backup_restore.php'> " . HERE_WORD . " </a> " . LOGIN_PASSWORD_NOT_CONFIRMED_2_MSG;
	}
?>

<?php include("lib/popup_msg.html"); ?>

<script>
	popup_msg.HidePopupMsg();
<?php	if ($password)	{	?>
	GetBackups();
<?php }	?>
</script>

</body>
</html>
